/*
    SPDX-FileCopyrightText: 2024 Dmitrii Fomchenkov <fomchenkovda@basealt.ru>
    SPDX-License-Identifier: GPL-2.0-or-later
*/
#include "settingtheme.h"

#include <KPackage/PackageLoader>
#include <KConfig>
#include <KConfigGroup>
#include <QProcess>
#include <KLocalizedString>

namespace {
    const QString LIGHTTHEME_ID(QLatin1String("org.kde.breeze.desktop"));
    const QString DARKTHEME_ID(QLatin1String("org.kde.breezedark.desktop"));
    const QString LIGHTTHEME_NAME(i18n("Light"));
    const QString DARKTHEME_NAME(i18n("Dark"));
}

LnfTheme::LnfTheme(Theme theme, QObject* parent) :
    QObject(parent)
{
    m_themePreviewPath = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/LookAndFeel")).filePath("preview");

    if (theme == Theme::DarkTheme) {
        m_themeId = DARKTHEME_ID;
        m_themeName = DARKTHEME_NAME;
        m_themePreviewPath.replace(LIGHTTHEME_ID, DARKTHEME_ID);
    } else {
        m_themeId = LIGHTTHEME_ID;
        m_themeName = LIGHTTHEME_NAME;
    }
}

SettingTheme::SettingTheme(QObject* parent) :
    QObject(parent), m_darkTheme(new LnfTheme(Theme::DarkTheme)), m_lightTheme(new LnfTheme(Theme::LightTheme))
{
    // Get current theme
    m_defaultTheme = KConfig(QLatin1String("kdeglobals"), KConfig::SimpleConfig)
        .group(QLatin1String("KDE"))
        .readEntry(QLatin1String("LookAndFeelPackage"), QString());

    connect(this, &SettingTheme::changed, this, &SettingTheme::changeTheme);
}

QObject* SettingTheme::getDarkTheme() const
{
    return m_darkTheme.data();
}

QObject* SettingTheme::getLightTheme() const
{
    return m_lightTheme.data();
}

void SettingTheme::changeTheme()
{
    QProcess::startDetached(QStringLiteral("plasma-apply-lookandfeel"),
                                QStringList({QStringLiteral("-a"), m_defaultTheme}));
}
