/*
    SPDX-FileCopyrightText: 2024 Dmitrii Fomchenkov <fomchenkovda@basealt.ru>
    SPDX-License-Identifier: GPL-2.0-or-later
*/
#pragma once

#include <QPointer>

enum class Theme { LightTheme, DarkTheme };

class LnfTheme : public QObject
{
    Q_OBJECT

public:
    explicit LnfTheme(Theme, QObject* = nullptr);

private:
    Q_PROPERTY(QString themeName MEMBER m_themeName NOTIFY changed)
    Q_PROPERTY(QString themeId MEMBER m_themeId NOTIFY changed)
    Q_PROPERTY(QString themePreviewPath MEMBER m_themePreviewPath NOTIFY changed)

    QString m_themeName;
    QString m_themeId;
    QString m_themePreviewPath;

    Q_SIGNAL void changed();
};

class SettingTheme : public QObject
{
    Q_OBJECT

public:
    explicit SettingTheme(QObject* = nullptr);

    Q_SIGNAL void changeDarkTheme();
    Q_SIGNAL void changeLightTheme();

private:
    Q_PROPERTY(QString defaultThemeId MEMBER m_defaultTheme NOTIFY changed)
    Q_PROPERTY(QObject* darkTheme READ getDarkTheme() NOTIFY changed)
    Q_PROPERTY(QObject* lightTheme READ getLightTheme() NOTIFY changed)

    QString m_defaultTheme;
    QPointer<LnfTheme> m_darkTheme;
    QPointer<LnfTheme> m_lightTheme;

    Q_SIGNAL void changed();

    Q_SLOT void changeTheme();

    QObject* getDarkTheme() const;
    QObject* getLightTheme() const;
};
