/*
    SPDX-FileCopyrightText: 2024 Dmitrii Fomchenkov <fomchenkovda@basealt.ru>
    SPDX-License-Identifier: GPL-2.0-or-later
*/
#include "welcomedistro.h"

#include <QSettings>

namespace {
    const QString OS_RELEASE_PATH(QLatin1String("/etc/os-release"));
    const QString DEFAULT_DISTRO_LOGO(QLatin1String("altlinux"));
    const QString DEFAULT_DISTRO_WEBSITE(QLatin1String("www.altlinux.org"));
}

WelcomeDistro::WelcomeDistro(QObject* parent) :
    QObject(parent), m_settingTheme(new SettingTheme()),
    m_distroName(getDistInfoVal(DistroInfo::NAME)),
    m_distroLogo(getDistInfoVal(DistroInfo::LOGO)),
    m_distroUrl(getDistInfoVal(DistroInfo::WEBSITE))
{
    if (m_distroLogo.isEmpty())
        m_distroUrl = DEFAULT_DISTRO_LOGO;

    if (m_distroUrl.isEmpty())
        m_distroUrl = DEFAULT_DISTRO_WEBSITE;
}

QObject* WelcomeDistro::getSettingTheme() const
{
    return m_settingTheme.data();
}

QString WelcomeDistro::getDistInfoVal(DistroInfo val) const
{
    QString param;
    switch (val) {
        case DistroInfo::NAME: param = QLatin1String("PRETTY_NAME"); break;
        case DistroInfo::LOGO: param = QLatin1String("LOGO"); break;
        case DistroInfo::WEBSITE: param = QLatin1String("HOME_URL"); break;
    }

    auto settingValue = QSettings(OS_RELEASE_PATH, QSettings::IniFormat)
        .value(param)
        .toString();
    
    return settingValue;
}
